# $Id: /mirror/gungho/lib/Gungho/Plugin.pm 6422 2007-04-09T02:27:47.388429Z lestrrat  $
#
# Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
# All rights reserved.

package Gungho::Plugin;
use strict;
use warnings;
use base qw(Gungho::Component);

1;

__END__

=head1 NAME

Gungho::Plugin - Gungho Plugin Base Class

=cut
